@@ -11,7 +11,7 @@ use Astro::Coord::ECI::TLE 0.059 qw{ :constants };
 use Astro::App::Satpass2::Utils qw{ @CARP_NOT };
 use Scalar::Util ();
 
-our $VERSION = '0.054';
+our $VERSION = '0.054_01';
 
 my @event_names;
 $event_names[PASS_EVENT_NONE]		= '';
@@ -257,7 +257,7 @@ BEGIN:VALARM
 TRIGGER:PT0M
 ACTION:DISPLAY
 END:VALARM
-SUMMARY:[% first.name %]
+SUMMARY:[% first.name( width = '' ) %]
 DESCRIPTION:
     [%- FOREACH evt IN events %][% punct %]
 	[%- format_detail( 'event', evt ) %]
